@@ -30,6 +30,7 @@
 
 #include <QComboBox>
 #include <QString>
+#include <QTime>
 
 #include <LXQt/Settings>
 
@@ -38,8 +39,8 @@ class PowerManagementSettings : public LXQt::Settings
     Q_OBJECT
 
 public:
-    PowerManagementSettings(QObject* parent = 0);
-    ~PowerManagementSettings();
+    PowerManagementSettings(QObject* parent = nullptr);
+    ~PowerManagementSettings() override;
 
     int getRunCheckLevel();
     void setRunCheckLevel(int newLevel);
@@ -89,6 +90,18 @@ public:
 
     bool isIdlenessWatcherEnabled();
     void setIdlenessWatcherEnabled(bool idlenessWatcherEnabled);
+    
+    bool isIdlenessBacklightWatcherEnabled();
+    void setIdlenessBacklightWatcherEnabled(bool idlenessBacklightWatcherEnabled);
+    
+    QTime getIdlenessBacklightTime();
+    void setIdlenessBacklightTime(QTime idlenessBacklightTime);
+    
+    int getBacklight();
+    void setBacklight(int backlight);
+    
+    bool isIdlenessBacklightOnBatteryDischargingEnabled();
+    void setIdlenessBacklightOnBatteryDischargingEnabled(bool enabled);
 };
 
 
