@@ -11,7 +11,7 @@
     <message>
         <location filename="../batterywatchersettings.ui" line="26"/>
         <source>E&amp;nable Battery Watcher</source>
-        <translation>バッテリー監視を有効にする(&amp;N)</translation>
+        <translation>バッテリーを監視する(&amp;N)</translation>
     </message>
     <message>
         <location filename="../batterywatchersettings.ui" line="54"/>
@@ -57,17 +57,17 @@
     <message>
         <location filename="../batterywatchersettings.ui" line="41"/>
         <source>When power is low then:</source>
-        <translation>電源が低いときには:</translation>
+        <translation>電源が低い時には:</translation>
     </message>
     <message>
         <location filename="../batterywatchersettings.ui" line="97"/>
         <source>Show icon:</source>
-        <translation>アイコンを表示:</translation>
+        <translation>トレイにアイコンを表示:</translation>
     </message>
     <message>
         <location filename="../batterywatchersettings.cpp" line="93"/>
         <source>built in</source>
-        <translation>ビルトイン</translation>
+        <translation>内蔵のアイコン</translation>
     </message>
     <message>
         <location filename="../batterywatchersettings.cpp" line="98"/>
@@ -80,7 +80,7 @@
     <message>
         <location filename="../idlenesswatchersettings.ui" line="17"/>
         <source>Enab&amp;le Idleness Watcher</source>
-        <translation>アイドル状態の監視(&amp;l)</translation>
+        <translation>アイドル状態を監視する(&amp;L)</translation>
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="38"/>
@@ -108,18 +108,18 @@
     <message>
         <location filename="../lidwatchersettings.ui" line="23"/>
         <source>Enable &amp;Lid Watcher</source>
-        <translation>フタの監視を有効にする(&amp;L)</translation>
+        <translation>ふたを監視する(&amp;L)</translation>
     </message>
     <message>
         <location filename="../lidwatchersettings.ui" line="38"/>
         <source>Action when lid is closed</source>
-        <translation>フタが閉じていたときの動作</translation>
+        <translation>ふたを閉じた時の動作</translation>
     </message>
     <message>
         <location filename="../lidwatchersettings.ui" line="50"/>
         <location filename="../lidwatchersettings.ui" line="115"/>
         <source>On Battery</source>
-        <translation>バッテリー動作時</translation>
+        <translation>バッテリー電源の時</translation>
     </message>
     <message>
         <location filename="../lidwatchersettings.ui" line="58"/>
@@ -145,12 +145,12 @@
         <location filename="../lidwatchersettings.ui" line="81"/>
         <location filename="../lidwatchersettings.ui" line="125"/>
         <source>On AC</source>
-        <translation>AC電源時</translation>
+        <translation>AC 電源の時</translation>
     </message>
     <message>
         <location filename="../lidwatchersettings.ui" line="94"/>
         <source>When &amp;using external monitor</source>
-        <translation>外部モニター使用時(&amp;u)</translation>
+        <translation>外部モニターの使用時には(&amp;U)</translation>
     </message>
 </context>
 <context>
@@ -168,7 +168,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="43"/>
         <source>Lid</source>
-        <translation>フタ</translation>
+        <translation>ふた</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="47"/>
@@ -186,7 +186,7 @@
     <message>
         <location filename="../helpers.cpp" line="36"/>
         <source>Lock screen</source>
-        <translation>スクリーンをロック</translation>
+        <translation>画面のロック</translation>
     </message>
     <message>
         <location filename="../helpers.cpp" line="37"/>
@@ -206,7 +206,7 @@
     <message>
         <location filename="../helpers.cpp" line="40"/>
         <source>Turn Off monitor(s)</source>
-        <translation type="unfinished"></translation>
+        <translation>モニターを消す</translation>
     </message>
 </context>
 </TS>
