@@ -200,21 +200,27 @@
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="126"/>
         <source>Suspending in %n second(s)</source>
-        <translation><numerusform>Sospensione tra %n secondo/i</numerusform>
-        <numerusform>Sospensione tra %n secondi</numerusform>
-        </translation></message>
+        <translation>
+            <numerusform>Sospensione tra %n secondo/i</numerusform>
+            <numerusform>Sospensione tra %n secondi</numerusform>
+        </translation>
+    </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="129"/>
         <source>Hibernating in %n second(s)</source>
-        <translation><numerusform>Ibernazione tra %n secondo</numerusform>
-        <numerusform>Ibernazione tra %n secondi</numerusform>
-        </translation></message>
+        <translation>
+            <numerusform>Ibernazione tra %n secondo</numerusform>
+            <numerusform>Ibernazione tra %n secondi</numerusform>
+        </translation>
+    </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="132"/>
         <source>Shutting down in %n second(s)</source>
-        <translation><numerusform>Arresto tra %n secondo/i</numerusform>
-        <numerusform>Arresto tra %n secondi</numerusform>
-        </translation></message>
+        <translation>
+            <numerusform>Arresto tra %n secondo/i</numerusform>
+            <numerusform>Arresto tra %n secondi</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PowerManagementd</name>
