@@ -209,17 +209,21 @@
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="129"/>
         <source>Hibernating in %n second(s)</source>
-        <translation><numerusform>Гибернация через %n секунду</numerusform>
-        <numerusform>Гибернация через %n секунды</numerusform>
-        <numerusform>Гибернация через %n секунд</numerusform>
-        </translation></message>
+        <translation>
+            <numerusform>Гибернация через %n секунду</numerusform>
+            <numerusform>Гибернация через %n секунды</numerusform>
+            <numerusform>Гибернация через %n секунд</numerusform>
+        </translation>
+    </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="132"/>
         <source>Shutting down in %n second(s)</source>
-        <translation><numerusform>Выключение через %n секунду</numerusform>
-        <numerusform>Выключение через %n секунды</numerusform>
-        <numerusform>Выключение через %n секунд</numerusform>
-        </translation></message>
+        <translation>
+            <numerusform>Выключение через %n секунду</numerusform>
+            <numerusform>Выключение через %n секунды</numerusform>
+            <numerusform>Выключение через %n секунд</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PowerManagementd</name>
@@ -272,7 +276,7 @@ You can configure it from settings... </source>
     <message>
         <location filename="../trayicon.cpp" line="114"/>
         <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
-        <translation>Значок в системном локе для управление энергопотреблением может быть включен в &lt;i&gt;Настройках управления энергопотреблением&lt;/i&gt;</translation>
+        <translation>Значок в системном лотке для управление энергопотреблением может быть включён в &lt;i&gt;Настройках управления энергопотреблением&lt;/i&gt;</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="116"/>
