@@ -200,21 +200,24 @@
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="126"/>
         <source>Suspending in %n second(s)</source>
-        <translation><numerusform>%n saniyedir beklemede</numerusform>
-        <numerusform>%n saniyedir beklemede</numerusform>
-        </translation></message>
+        <translation>
+            <numerusform>%n saniyedir beklemede</numerusform>
+        </translation>
+    </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="129"/>
         <source>Hibernating in %n second(s)</source>
-        <translation><numerusform>%n saniyedir uykuda</numerusform>
-        <numerusform>%n saniyedir uykuda</numerusform>
-        </translation></message>
+        <translation>
+            <numerusform>%n saniyedir uykuda</numerusform>
+        </translation>
+    </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="132"/>
         <source>Shutting down in %n second(s)</source>
-        <translation><numerusform>%n saniyede kapanıyor</numerusform>
-        <numerusform>%n saniyede kapanıyor</numerusform>
-        </translation></message>
+        <translation>
+            <numerusform>%n saniyede kapanıyor</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>PowerManagementd</name>
